# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'file_widget.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_file_widget(object):
    def setupUi(self, file_widget):
        file_widget.setObjectName("file_widget")
        file_widget.resize(1034, 865)
        self.verticalLayout = QtWidgets.QVBoxLayout(file_widget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.aspects = QtWidgets.QTabWidget(file_widget)
        self.aspects.setToolTip("")
        self.aspects.setTabPosition(QtWidgets.QTabWidget.West)
        self.aspects.setDocumentMode(False)
        self.aspects.setObjectName("aspects")
        self.channels_tab = QtWidgets.QWidget()
        self.channels_tab.setObjectName("channels_tab")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.channels_tab)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.splitter = QtWidgets.QSplitter(self.channels_tab)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.splitter)
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.channel_view = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.channel_view.setObjectName("channel_view")
        self.channel_view.addItem("")
        self.channel_view.addItem("")
        self.channel_view.addItem("")
        self.verticalLayout_4.addWidget(self.channel_view)
        self.channels_tree = TreeWidget(self.verticalLayoutWidget)
        self.channels_tree.setObjectName("channels_tree")
        self.verticalLayout_4.addWidget(self.channels_tree)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.load_channel_list_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.load_channel_list_btn.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.load_channel_list_btn.setIcon(icon)
        self.load_channel_list_btn.setObjectName("load_channel_list_btn")
        self.horizontalLayout_2.addWidget(self.load_channel_list_btn)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.save_channel_list_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.save_channel_list_btn.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.save_channel_list_btn.setIcon(icon1)
        self.save_channel_list_btn.setObjectName("save_channel_list_btn")
        self.horizontalLayout_2.addWidget(self.save_channel_list_btn)
        self.select_all_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.select_all_btn.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/checkmark.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.select_all_btn.setIcon(icon2)
        self.select_all_btn.setObjectName("select_all_btn")
        self.horizontalLayout_2.addWidget(self.select_all_btn)
        self.clear_channels_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.clear_channels_btn.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/erase.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.clear_channels_btn.setIcon(icon3)
        self.clear_channels_btn.setObjectName("clear_channels_btn")
        self.horizontalLayout_2.addWidget(self.clear_channels_btn)
        self.advanced_search_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.advanced_search_btn.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.advanced_search_btn.setIcon(icon4)
        self.advanced_search_btn.setObjectName("advanced_search_btn")
        self.horizontalLayout_2.addWidget(self.advanced_search_btn)
        self.create_window_btn = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.create_window_btn.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/graph.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.create_window_btn.setIcon(icon5)
        self.create_window_btn.setObjectName("create_window_btn")
        self.horizontalLayout_2.addWidget(self.create_window_btn)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.verticalLayout_4.addLayout(self.horizontalLayout_2)
        self.verticalLayout_5.addWidget(self.splitter)
        self.aspects.addTab(self.channels_tab, icon5, "")
        self.modify = QtWidgets.QWidget()
        self.modify.setObjectName("modify")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.modify)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.filter_view = QtWidgets.QComboBox(self.modify)
        self.filter_view.setObjectName("filter_view")
        self.filter_view.addItem("")
        self.filter_view.addItem("")
        self.filter_view.addItem("")
        self.verticalLayout_2.addWidget(self.filter_view)
        self.filter_tree = TreeWidget(self.modify)
        self.filter_tree.setObjectName("filter_tree")
        self.verticalLayout_2.addWidget(self.filter_tree)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.load_filter_list_btn = QtWidgets.QPushButton(self.modify)
        self.load_filter_list_btn.setText("")
        self.load_filter_list_btn.setIcon(icon)
        self.load_filter_list_btn.setObjectName("load_filter_list_btn")
        self.horizontalLayout_4.addWidget(self.load_filter_list_btn)
        self.save_filter_list_btn = QtWidgets.QPushButton(self.modify)
        self.save_filter_list_btn.setText("")
        self.save_filter_list_btn.setIcon(icon1)
        self.save_filter_list_btn.setObjectName("save_filter_list_btn")
        self.horizontalLayout_4.addWidget(self.save_filter_list_btn)
        self.clear_filter_btn = QtWidgets.QPushButton(self.modify)
        self.clear_filter_btn.setText("")
        self.clear_filter_btn.setIcon(icon3)
        self.clear_filter_btn.setObjectName("clear_filter_btn")
        self.horizontalLayout_4.addWidget(self.clear_filter_btn)
        self.advanced_serch_filter_btn = QtWidgets.QPushButton(self.modify)
        self.advanced_serch_filter_btn.setText("")
        self.advanced_serch_filter_btn.setIcon(icon4)
        self.advanced_serch_filter_btn.setObjectName("advanced_serch_filter_btn")
        self.horizontalLayout_4.addWidget(self.advanced_serch_filter_btn)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.label = QtWidgets.QLabel(self.modify)
        self.label.setObjectName("label")
        self.verticalLayout_6.addWidget(self.label)
        self.selected_filter_channels = QtWidgets.QListWidget(self.modify)
        self.selected_filter_channels.setViewMode(QtWidgets.QListView.ListMode)
        self.selected_filter_channels.setUniformItemSizes(True)
        self.selected_filter_channels.setObjectName("selected_filter_channels")
        self.verticalLayout_6.addWidget(self.selected_filter_channels)
        self.horizontalLayout.addLayout(self.verticalLayout_6)
        spacerItem3 = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setSpacing(2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.cut_group = QtWidgets.QGroupBox(self.modify)
        self.cut_group.setCheckable(True)
        self.cut_group.setChecked(False)
        self.cut_group.setObjectName("cut_group")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.cut_group)
        self.gridLayout_19.setContentsMargins(2, 2, 2, 2)
        self.gridLayout_19.setHorizontalSpacing(2)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.label_59 = QtWidgets.QLabel(self.cut_group)
        self.label_59.setObjectName("label_59")
        self.gridLayout_19.addWidget(self.label_59, 0, 0, 1, 1)
        self.cut_stop = QtWidgets.QDoubleSpinBox(self.cut_group)
        self.cut_stop.setDecimals(6)
        self.cut_stop.setMaximum(999999.999999)
        self.cut_stop.setObjectName("cut_stop")
        self.gridLayout_19.addWidget(self.cut_stop, 1, 1, 1, 1)
        self.whence = QtWidgets.QCheckBox(self.cut_group)
        self.whence.setObjectName("whence")
        self.gridLayout_19.addWidget(self.whence, 3, 0, 1, 1)
        self.label_60 = QtWidgets.QLabel(self.cut_group)
        self.label_60.setObjectName("label_60")
        self.gridLayout_19.addWidget(self.label_60, 1, 0, 1, 1)
        self.cut_start = QtWidgets.QDoubleSpinBox(self.cut_group)
        self.cut_start.setDecimals(6)
        self.cut_start.setMaximum(999999.999999)
        self.cut_start.setObjectName("cut_start")
        self.gridLayout_19.addWidget(self.cut_start, 0, 1, 1, 1)
        self.cut_time_from_zero = QtWidgets.QCheckBox(self.cut_group)
        self.cut_time_from_zero.setObjectName("cut_time_from_zero")
        self.gridLayout_19.addWidget(self.cut_time_from_zero, 4, 0, 1, 1)
        self.verticalLayout_3.addWidget(self.cut_group)
        self.resample_group = QtWidgets.QGroupBox(self.modify)
        self.resample_group.setCheckable(True)
        self.resample_group.setChecked(False)
        self.resample_group.setObjectName("resample_group")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.resample_group)
        self.gridLayout_21.setContentsMargins(2, 2, 2, 2)
        self.gridLayout_21.setHorizontalSpacing(2)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.raster_type_step = QtWidgets.QRadioButton(self.resample_group)
        self.raster_type_step.setChecked(True)
        self.raster_type_step.setObjectName("raster_type_step")
        self.gridLayout_21.addWidget(self.raster_type_step, 0, 0, 1, 1)
        self.raster = QtWidgets.QDoubleSpinBox(self.resample_group)
        self.raster.setMinimumSize(QtCore.QSize(100, 0))
        self.raster.setDecimals(6)
        self.raster.setMinimum(1e-06)
        self.raster.setObjectName("raster")
        self.gridLayout_21.addWidget(self.raster, 0, 1, 1, 1)
        self.resample_time_from_zero = QtWidgets.QCheckBox(self.resample_group)
        self.resample_time_from_zero.setObjectName("resample_time_from_zero")
        self.gridLayout_21.addWidget(self.resample_time_from_zero, 3, 0, 1, 1)
        self.raster_type_channel = QtWidgets.QRadioButton(self.resample_group)
        self.raster_type_channel.setObjectName("raster_type_channel")
        self.gridLayout_21.addWidget(self.raster_type_channel, 2, 0, 1, 1)
        self.raster_channel = QtWidgets.QComboBox(self.resample_group)
        self.raster_channel.setEnabled(False)
        self.raster_channel.setInsertPolicy(QtWidgets.QComboBox.InsertAtBottom)
        self.raster_channel.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLengthWithIcon)
        self.raster_channel.setObjectName("raster_channel")
        self.gridLayout_21.addWidget(self.raster_channel, 2, 1, 1, 1)
        self.raster_search_btn = QtWidgets.QPushButton(self.resample_group)
        self.raster_search_btn.setText("")
        self.raster_search_btn.setIcon(icon4)
        self.raster_search_btn.setObjectName("raster_search_btn")
        self.gridLayout_21.addWidget(self.raster_search_btn, 2, 2, 1, 1)
        self.gridLayout_21.setColumnStretch(1, 1)
        self.verticalLayout_3.addWidget(self.resample_group)
        self.groupBox_10 = QtWidgets.QGroupBox(self.modify)
        self.groupBox_10.setObjectName("groupBox_10")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.groupBox_10)
        self.verticalLayout_20.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_20.setSpacing(2)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.output_format = QtWidgets.QComboBox(self.groupBox_10)
        self.output_format.setObjectName("output_format")
        self.output_format.addItem("")
        self.output_format.addItem("")
        self.output_format.addItem("")
        self.output_format.addItem("")
        self.output_format.addItem("")
        self.verticalLayout_20.addWidget(self.output_format)
        self.output_options = QtWidgets.QStackedWidget(self.groupBox_10)
        self.output_options.setObjectName("output_options")
        self.MDF = QtWidgets.QWidget()
        self.MDF.setObjectName("MDF")
        self.gridLayout_22 = QtWidgets.QGridLayout(self.MDF)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.mdf_split_size = QtWidgets.QDoubleSpinBox(self.MDF)
        self.mdf_split_size.setMaximum(4.0)
        self.mdf_split_size.setObjectName("mdf_split_size")
        self.gridLayout_22.addWidget(self.mdf_split_size, 4, 1, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.MDF)
        self.label_29.setObjectName("label_29")
        self.gridLayout_22.addWidget(self.label_29, 2, 0, 1, 1)
        self.line_14 = QtWidgets.QFrame(self.MDF)
        self.line_14.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_14.setObjectName("line_14")
        self.gridLayout_22.addWidget(self.line_14, 1, 0, 1, 2)
        self.mdf_compression = QtWidgets.QComboBox(self.MDF)
        self.mdf_compression.setObjectName("mdf_compression")
        self.gridLayout_22.addWidget(self.mdf_compression, 2, 1, 1, 1)
        self.mdf_split = QtWidgets.QCheckBox(self.MDF)
        self.mdf_split.setChecked(True)
        self.mdf_split.setObjectName("mdf_split")
        self.gridLayout_22.addWidget(self.mdf_split, 3, 0, 1, 1)
        self.label_27 = QtWidgets.QLabel(self.MDF)
        self.label_27.setObjectName("label_27")
        self.gridLayout_22.addWidget(self.label_27, 0, 0, 1, 1)
        self.groupBox_9 = QtWidgets.QGroupBox(self.MDF)
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.scramble_btn = QtWidgets.QPushButton(self.groupBox_9)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/scramble.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.scramble_btn.setIcon(icon6)
        self.scramble_btn.setObjectName("scramble_btn")
        self.gridLayout_20.addWidget(self.scramble_btn, 1, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_20.addItem(spacerItem4, 1, 1, 1, 1)
        self.label_61 = QtWidgets.QLabel(self.groupBox_9)
        self.label_61.setWordWrap(True)
        self.label_61.setObjectName("label_61")
        self.gridLayout_20.addWidget(self.label_61, 0, 0, 1, 2)
        self.gridLayout_22.addWidget(self.groupBox_9, 5, 0, 1, 2)
        self.label_28 = QtWidgets.QLabel(self.MDF)
        self.label_28.setObjectName("label_28")
        self.gridLayout_22.addWidget(self.label_28, 4, 0, 1, 1)
        self.mdf_version = QtWidgets.QComboBox(self.MDF)
        self.mdf_version.setMinimumSize(QtCore.QSize(200, 0))
        self.mdf_version.setObjectName("mdf_version")
        self.gridLayout_22.addWidget(self.mdf_version, 0, 1, 1, 1)
        self.output_options.addWidget(self.MDF)
        self.HDF5 = QtWidgets.QWidget()
        self.HDF5.setObjectName("HDF5")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.HDF5)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.time_as_date = QtWidgets.QCheckBox(self.HDF5)
        self.time_as_date.setObjectName("time_as_date")
        self.gridLayout_2.addWidget(self.time_as_date, 2, 0, 1, 1)
        self.empty_channels = QtWidgets.QComboBox(self.HDF5)
        self.empty_channels.setObjectName("empty_channels")
        self.gridLayout_2.addWidget(self.empty_channels, 8, 1, 1, 1)
        self.time_from_zero = QtWidgets.QCheckBox(self.HDF5)
        self.time_from_zero.setObjectName("time_from_zero")
        self.gridLayout_2.addWidget(self.time_from_zero, 1, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem5, 9, 0, 1, 1)
        self.reduce_memory_usage = QtWidgets.QCheckBox(self.HDF5)
        self.reduce_memory_usage.setObjectName("reduce_memory_usage")
        self.gridLayout_2.addWidget(self.reduce_memory_usage, 6, 0, 1, 1)
        self.label_67 = QtWidgets.QLabel(self.HDF5)
        self.label_67.setObjectName("label_67")
        self.gridLayout_2.addWidget(self.label_67, 7, 0, 1, 1)
        self.label_65 = QtWidgets.QLabel(self.HDF5)
        self.label_65.setObjectName("label_65")
        self.gridLayout_2.addWidget(self.label_65, 8, 0, 1, 1)
        self.export_compression = QtWidgets.QComboBox(self.HDF5)
        self.export_compression.setObjectName("export_compression")
        self.gridLayout_2.addWidget(self.export_compression, 7, 1, 1, 1)
        self.line_30 = QtWidgets.QFrame(self.HDF5)
        self.line_30.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_30.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_30.setObjectName("line_30")
        self.gridLayout_2.addWidget(self.line_30, 4, 0, 1, 2)
        self.single_time_base = QtWidgets.QCheckBox(self.HDF5)
        self.single_time_base.setObjectName("single_time_base")
        self.gridLayout_2.addWidget(self.single_time_base, 0, 0, 1, 1)
        self.use_display_names = QtWidgets.QCheckBox(self.HDF5)
        self.use_display_names.setObjectName("use_display_names")
        self.gridLayout_2.addWidget(self.use_display_names, 5, 0, 1, 1)
        self.raw = QtWidgets.QCheckBox(self.HDF5)
        self.raw.setObjectName("raw")
        self.gridLayout_2.addWidget(self.raw, 3, 0, 1, 1)
        self.output_options.addWidget(self.HDF5)
        self.MAT = QtWidgets.QWidget()
        self.MAT.setObjectName("MAT")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.MAT)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.use_display_names_mat = QtWidgets.QCheckBox(self.MAT)
        self.use_display_names_mat.setObjectName("use_display_names_mat")
        self.gridLayout_3.addWidget(self.use_display_names_mat, 5, 0, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.MAT)
        self.label_19.setObjectName("label_19")
        self.gridLayout_3.addWidget(self.label_19, 10, 0, 1, 1)
        self.time_from_zero_mat = QtWidgets.QCheckBox(self.MAT)
        self.time_from_zero_mat.setObjectName("time_from_zero_mat")
        self.gridLayout_3.addWidget(self.time_from_zero_mat, 1, 0, 1, 1)
        self.label_70 = QtWidgets.QLabel(self.MAT)
        self.label_70.setObjectName("label_70")
        self.gridLayout_3.addWidget(self.label_70, 7, 0, 1, 1)
        self.label_69 = QtWidgets.QLabel(self.MAT)
        self.label_69.setObjectName("label_69")
        self.gridLayout_3.addWidget(self.label_69, 9, 0, 1, 1)
        self.export_compression_mat = QtWidgets.QComboBox(self.MAT)
        self.export_compression_mat.setObjectName("export_compression_mat")
        self.gridLayout_3.addWidget(self.export_compression_mat, 7, 1, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 2, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem6, 11, 0, 1, 1)
        self.line_31 = QtWidgets.QFrame(self.MAT)
        self.line_31.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_31.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_31.setObjectName("line_31")
        self.gridLayout_3.addWidget(self.line_31, 4, 0, 1, 2)
        self.single_time_base_mat = QtWidgets.QCheckBox(self.MAT)
        self.single_time_base_mat.setObjectName("single_time_base_mat")
        self.gridLayout_3.addWidget(self.single_time_base_mat, 0, 0, 1, 1)
        self.empty_channels_mat = QtWidgets.QComboBox(self.MAT)
        self.empty_channels_mat.setObjectName("empty_channels_mat")
        self.gridLayout_3.addWidget(self.empty_channels_mat, 8, 1, 1, 1)
        self.mat_format = QtWidgets.QComboBox(self.MAT)
        self.mat_format.setObjectName("mat_format")
        self.gridLayout_3.addWidget(self.mat_format, 9, 1, 1, 1)
        self.reduce_memory_usage_mat = QtWidgets.QCheckBox(self.MAT)
        self.reduce_memory_usage_mat.setObjectName("reduce_memory_usage_mat")
        self.gridLayout_3.addWidget(self.reduce_memory_usage_mat, 6, 0, 1, 1)
        self.oned_as = QtWidgets.QComboBox(self.MAT)
        self.oned_as.setObjectName("oned_as")
        self.gridLayout_3.addWidget(self.oned_as, 10, 1, 1, 1)
        self.time_as_date_mat = QtWidgets.QCheckBox(self.MAT)
        self.time_as_date_mat.setObjectName("time_as_date_mat")
        self.gridLayout_3.addWidget(self.time_as_date_mat, 2, 0, 1, 1)
        self.label_68 = QtWidgets.QLabel(self.MAT)
        self.label_68.setObjectName("label_68")
        self.gridLayout_3.addWidget(self.label_68, 8, 0, 1, 1)
        self.raw_mat = QtWidgets.QCheckBox(self.MAT)
        self.raw_mat.setObjectName("raw_mat")
        self.gridLayout_3.addWidget(self.raw_mat, 3, 0, 1, 1)
        self.output_options.addWidget(self.MAT)
        self.CSV = QtWidgets.QWidget()
        self.CSV.setObjectName("CSV")
        self.gridLayout = QtWidgets.QGridLayout(self.CSV)
        self.gridLayout.setContentsMargins(2, 2, 2, 2)
        self.gridLayout.setSpacing(2)
        self.gridLayout.setObjectName("gridLayout")
        self.quotechar = QtWidgets.QLineEdit(self.CSV)
        self.quotechar.setMaxLength(1)
        self.quotechar.setObjectName("quotechar")
        self.gridLayout.addWidget(self.quotechar, 11, 1, 1, 2)
        self.label_5 = QtWidgets.QLabel(self.CSV)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 11, 0, 1, 1)
        self.use_display_names_csv = QtWidgets.QCheckBox(self.CSV)
        self.use_display_names_csv.setObjectName("use_display_names_csv")
        self.gridLayout.addWidget(self.use_display_names_csv, 5, 0, 1, 3)
        self.single_time_base_csv = QtWidgets.QCheckBox(self.CSV)
        self.single_time_base_csv.setObjectName("single_time_base_csv")
        self.gridLayout.addWidget(self.single_time_base_csv, 0, 0, 1, 3)
        self.lineterminator = QtWidgets.QLineEdit(self.CSV)
        self.lineterminator.setObjectName("lineterminator")
        self.gridLayout.addWidget(self.lineterminator, 10, 1, 1, 2)
        self.time_as_date_csv = QtWidgets.QCheckBox(self.CSV)
        self.time_as_date_csv.setObjectName("time_as_date_csv")
        self.gridLayout.addWidget(self.time_as_date_csv, 2, 0, 1, 3)
        self.raw_csv = QtWidgets.QCheckBox(self.CSV)
        self.raw_csv.setObjectName("raw_csv")
        self.gridLayout.addWidget(self.raw_csv, 3, 0, 1, 3)
        self.label_2 = QtWidgets.QLabel(self.CSV)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 7, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.CSV)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 9, 0, 1, 1)
        self.escapechar = QtWidgets.QLineEdit(self.CSV)
        self.escapechar.setInputMask("")
        self.escapechar.setMaxLength(1)
        self.escapechar.setObjectName("escapechar")
        self.gridLayout.addWidget(self.escapechar, 9, 1, 1, 2)
        self.line_32 = QtWidgets.QFrame(self.CSV)
        self.line_32.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_32.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_32.setObjectName("line_32")
        self.gridLayout.addWidget(self.line_32, 4, 0, 1, 3)
        self.time_from_zero_csv = QtWidgets.QCheckBox(self.CSV)
        self.time_from_zero_csv.setObjectName("time_from_zero_csv")
        self.gridLayout.addWidget(self.time_from_zero_csv, 1, 0, 1, 3)
        self.label_4 = QtWidgets.QLabel(self.CSV)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 10, 0, 1, 1)
        self.doublequote = QtWidgets.QCheckBox(self.CSV)
        self.doublequote.setChecked(True)
        self.doublequote.setObjectName("doublequote")
        self.gridLayout.addWidget(self.doublequote, 8, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.CSV)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 12, 0, 1, 1)
        self.quoting = QtWidgets.QComboBox(self.CSV)
        self.quoting.setObjectName("quoting")
        self.quoting.addItem("")
        self.quoting.addItem("")
        self.quoting.addItem("")
        self.quoting.addItem("")
        self.gridLayout.addWidget(self.quoting, 12, 1, 1, 2)
        self.delimiter = QtWidgets.QLineEdit(self.CSV)
        self.delimiter.setMaxLength(1)
        self.delimiter.setClearButtonEnabled(False)
        self.delimiter.setObjectName("delimiter")
        self.gridLayout.addWidget(self.delimiter, 7, 1, 1, 2)
        self.label_66 = QtWidgets.QLabel(self.CSV)
        self.label_66.setObjectName("label_66")
        self.gridLayout.addWidget(self.label_66, 6, 0, 1, 1)
        self.empty_channels_csv = QtWidgets.QComboBox(self.CSV)
        self.empty_channels_csv.setObjectName("empty_channels_csv")
        self.gridLayout.addWidget(self.empty_channels_csv, 6, 1, 1, 2)
        self.output_options.addWidget(self.CSV)
        self.verticalLayout_20.addWidget(self.output_options)
        self.verticalLayout_3.addWidget(self.groupBox_10)
        spacerItem7 = QtWidgets.QSpacerItem(20, 2, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem7)
        self.apply_btn = QtWidgets.QPushButton(self.modify)
        self.apply_btn.setIcon(icon2)
        self.apply_btn.setObjectName("apply_btn")
        self.verticalLayout_3.addWidget(self.apply_btn)
        self.verticalLayout_3.setStretch(3, 1)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.horizontalLayout.setStretch(0, 1)
        self.horizontalLayout.setStretch(1, 1)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/convert.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.aspects.addTab(self.modify, icon7, "")
        self.extract_bus_tab = QtWidgets.QWidget()
        self.extract_bus_tab.setObjectName("extract_bus_tab")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.extract_bus_tab)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_12 = QtWidgets.QLabel(self.extract_bus_tab)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_3.addWidget(self.label_12)
        self.prefix = QtWidgets.QLineEdit(self.extract_bus_tab)
        self.prefix.setMinimumSize(QtCore.QSize(215, 0))
        self.prefix.setObjectName("prefix")
        self.horizontalLayout_3.addWidget(self.prefix)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem8)
        self.horizontalLayout_3.setStretch(2, 1)
        self.gridLayout_8.addLayout(self.horizontalLayout_3, 3, 0, 1, 2)
        self.groupBox_2 = QtWidgets.QGroupBox(self.extract_bus_tab)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_5.setContentsMargins(2, 2, 2, 2)
        self.gridLayout_5.setSpacing(2)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label__1 = QtWidgets.QLabel(self.groupBox_2)
        self.label__1.setObjectName("label__1")
        self.gridLayout_5.addWidget(self.label__1, 0, 0, 1, 1)
        self.line_12 = QtWidgets.QFrame(self.groupBox_2)
        self.line_12.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_12.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_12.setObjectName("line_12")
        self.gridLayout_5.addWidget(self.line_12, 3, 0, 1, 3)
        self.label_26 = QtWidgets.QLabel(self.groupBox_2)
        self.label_26.setText("")
        self.label_26.setObjectName("label_26")
        self.gridLayout_5.addWidget(self.label_26, 2, 1, 1, 1)
        self.extract_bus_format = QtWidgets.QComboBox(self.groupBox_2)
        self.extract_bus_format.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.extract_bus_format.setObjectName("extract_bus_format")
        self.gridLayout_5.addWidget(self.extract_bus_format, 1, 1, 1, 2)
        self.extract_bus_compression = QtWidgets.QComboBox(self.groupBox_2)
        self.extract_bus_compression.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.extract_bus_compression.setObjectName("extract_bus_compression")
        self.gridLayout_5.addWidget(self.extract_bus_compression, 0, 1, 1, 2)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem9, 4, 0, 1, 1)
        self.extract_bus_btn = QtWidgets.QPushButton(self.groupBox_2)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/down.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.extract_bus_btn.setIcon(icon8)
        self.extract_bus_btn.setObjectName("extract_bus_btn")
        self.gridLayout_5.addWidget(self.extract_bus_btn, 4, 1, 1, 2)
        self.label_24 = QtWidgets.QLabel(self.groupBox_2)
        self.label_24.setObjectName("label_24")
        self.gridLayout_5.addWidget(self.label_24, 1, 0, 1, 1)
        self.gridLayout_8.addWidget(self.groupBox_2, 5, 0, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(self.extract_bus_tab)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_4.setContentsMargins(2, 2, 2, 2)
        self.gridLayout_4.setSpacing(2)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.load_can_database_btn = QtWidgets.QPushButton(self.tab)
        self.load_can_database_btn.setIcon(icon)
        self.load_can_database_btn.setObjectName("load_can_database_btn")
        self.gridLayout_4.addWidget(self.load_can_database_btn, 0, 0, 1, 1)
        self.can_database_list = MinimalListWidget(self.tab)
        self.can_database_list.setObjectName("can_database_list")
        self.gridLayout_4.addWidget(self.can_database_list, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_7.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_7.setSpacing(2)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.load_lin_database_btn = QtWidgets.QPushButton(self.tab_2)
        self.load_lin_database_btn.setIcon(icon)
        self.load_lin_database_btn.setObjectName("load_lin_database_btn")
        self.verticalLayout_7.addWidget(self.load_lin_database_btn)
        self.lin_database_list = MinimalListWidget(self.tab_2)
        self.lin_database_list.setObjectName("lin_database_list")
        self.verticalLayout_7.addWidget(self.lin_database_list)
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout_8.addWidget(self.tabWidget, 2, 0, 1, 2)
        self.groupBox_3 = QtWidgets.QGroupBox(self.extract_bus_tab)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_6.setContentsMargins(-1, 2, 2, 2)
        self.gridLayout_6.setSpacing(2)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_10 = QtWidgets.QLabel(self.groupBox_3)
        self.label_10.setObjectName("label_10")
        self.gridLayout_6.addWidget(self.label_10, 11, 0, 1, 1)
        self.single_time_base_bus = QtWidgets.QCheckBox(self.groupBox_3)
        self.single_time_base_bus.setObjectName("single_time_base_bus")
        self.gridLayout_6.addWidget(self.single_time_base_bus, 0, 0, 1, 4)
        self.doublequote_bus = QtWidgets.QCheckBox(self.groupBox_3)
        self.doublequote_bus.setChecked(True)
        self.doublequote_bus.setObjectName("doublequote_bus")
        self.gridLayout_6.addWidget(self.doublequote_bus, 7, 0, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_3)
        self.label_23.setObjectName("label_23")
        self.gridLayout_6.addWidget(self.label_23, 4, 0, 1, 1)
        self.label_25 = QtWidgets.QLabel(self.groupBox_3)
        self.label_25.setObjectName("label_25")
        self.gridLayout_6.addWidget(self.label_25, 5, 0, 1, 2)
        self.label_9 = QtWidgets.QLabel(self.groupBox_3)
        self.label_9.setObjectName("label_9")
        self.gridLayout_6.addWidget(self.label_9, 8, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_3)
        self.label_7.setObjectName("label_7")
        self.gridLayout_6.addWidget(self.label_7, 12, 0, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_3)
        self.label_11.setObjectName("label_11")
        self.gridLayout_6.addWidget(self.label_11, 10, 0, 1, 2)
        self.bus_time_as_date = QtWidgets.QCheckBox(self.groupBox_3)
        self.bus_time_as_date.setObjectName("bus_time_as_date")
        self.gridLayout_6.addWidget(self.bus_time_as_date, 2, 0, 1, 3)
        self.time_from_zero_bus = QtWidgets.QCheckBox(self.groupBox_3)
        self.time_from_zero_bus.setObjectName("time_from_zero_bus")
        self.gridLayout_6.addWidget(self.time_from_zero_bus, 1, 0, 1, 3)
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setObjectName("label_8")
        self.gridLayout_6.addWidget(self.label_8, 6, 0, 1, 1)
        self.ignore_invalid_signals_csv = QtWidgets.QCheckBox(self.groupBox_3)
        self.ignore_invalid_signals_csv.setObjectName("ignore_invalid_signals_csv")
        self.gridLayout_6.addWidget(self.ignore_invalid_signals_csv, 3, 0, 1, 3)
        self.export_raster_bus = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.export_raster_bus.setDecimals(6)
        self.export_raster_bus.setObjectName("export_raster_bus")
        self.gridLayout_6.addWidget(self.export_raster_bus, 4, 3, 1, 1)
        self.empty_channels_bus = QtWidgets.QComboBox(self.groupBox_3)
        self.empty_channels_bus.setObjectName("empty_channels_bus")
        self.gridLayout_6.addWidget(self.empty_channels_bus, 5, 3, 1, 1)
        self.delimiter_bus = QtWidgets.QLineEdit(self.groupBox_3)
        self.delimiter_bus.setMaxLength(1)
        self.delimiter_bus.setClearButtonEnabled(False)
        self.delimiter_bus.setObjectName("delimiter_bus")
        self.gridLayout_6.addWidget(self.delimiter_bus, 6, 3, 1, 1)
        self.escapechar_bus = QtWidgets.QLineEdit(self.groupBox_3)
        self.escapechar_bus.setInputMask("")
        self.escapechar_bus.setMaxLength(1)
        self.escapechar_bus.setObjectName("escapechar_bus")
        self.gridLayout_6.addWidget(self.escapechar_bus, 8, 3, 1, 1)
        self.lineterminator_bus = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineterminator_bus.setObjectName("lineterminator_bus")
        self.gridLayout_6.addWidget(self.lineterminator_bus, 10, 3, 1, 1)
        self.quotechar_bus = QtWidgets.QLineEdit(self.groupBox_3)
        self.quotechar_bus.setMaxLength(1)
        self.quotechar_bus.setObjectName("quotechar_bus")
        self.gridLayout_6.addWidget(self.quotechar_bus, 11, 3, 1, 1)
        self.quoting_bus = QtWidgets.QComboBox(self.groupBox_3)
        self.quoting_bus.setObjectName("quoting_bus")
        self.quoting_bus.addItem("")
        self.quoting_bus.addItem("")
        self.quoting_bus.addItem("")
        self.quoting_bus.addItem("")
        self.gridLayout_6.addWidget(self.quoting_bus, 12, 3, 1, 1)
        self.extract_bus_csv_btn = QtWidgets.QPushButton(self.groupBox_3)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/csv.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.extract_bus_csv_btn.setIcon(icon9)
        self.extract_bus_csv_btn.setObjectName("extract_bus_csv_btn")
        self.gridLayout_6.addWidget(self.extract_bus_csv_btn, 14, 3, 1, 1)
        self.line_13 = QtWidgets.QFrame(self.groupBox_3)
        self.line_13.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_13.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_13.setObjectName("line_13")
        self.gridLayout_6.addWidget(self.line_13, 13, 0, 1, 4)
        self.gridLayout_6.setColumnStretch(0, 1)
        self.gridLayout_8.addWidget(self.groupBox_3, 5, 1, 1, 1)
        self.output_info_bus = QtWidgets.QTextEdit(self.extract_bus_tab)
        self.output_info_bus.setReadOnly(True)
        self.output_info_bus.setObjectName("output_info_bus")
        self.gridLayout_8.addWidget(self.output_info_bus, 1, 2, 5, 2)
        self.consolidated_j1939 = QtWidgets.QCheckBox(self.extract_bus_tab)
        self.consolidated_j1939.setChecked(True)
        self.consolidated_j1939.setObjectName("consolidated_j1939")
        self.gridLayout_8.addWidget(self.consolidated_j1939, 4, 0, 1, 2)
        self.gridLayout_8.setColumnStretch(0, 1)
        self.gridLayout_8.setColumnStretch(1, 1)
        self.gridLayout_8.setColumnStretch(2, 1)
        self.gridLayout_8.setColumnStretch(3, 1)
        self.aspects.addTab(self.extract_bus_tab, icon8, "")
        self.info_tab = QtWidgets.QWidget()
        self.info_tab.setObjectName("info_tab")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.info_tab)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.info = QtWidgets.QTreeWidget(self.info_tab)
        self.info.setUniformRowHeights(False)
        self.info.setObjectName("info")
        self.gridLayout_9.addWidget(self.info, 0, 0, 1, 1)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.aspects.addTab(self.info_tab, icon10, "")
        self.attachments_tab = QtWidgets.QWidget()
        self.attachments_tab.setObjectName("attachments_tab")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.attachments_tab)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.attachments = QtWidgets.QListWidget(self.attachments_tab)
        self.attachments.setObjectName("attachments")
        self.verticalLayout_10.addWidget(self.attachments)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/attach.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.aspects.addTab(self.attachments_tab, icon11, "")
        self.verticalLayout.addWidget(self.aspects)

        self.retranslateUi(file_widget)
        self.aspects.setCurrentIndex(0)
        self.output_options.setCurrentIndex(0)
        self.quoting.setCurrentIndex(1)
        self.tabWidget.setCurrentIndex(0)
        self.quoting_bus.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(file_widget)

    def retranslateUi(self, file_widget):
        _translate = QtCore.QCoreApplication.translate
        file_widget.setWindowTitle(_translate("file_widget", "Form"))
        self.channel_view.setItemText(0, _translate("file_widget", "Natural sort"))
        self.channel_view.setItemText(1, _translate("file_widget", "Internal file structure"))
        self.channel_view.setItemText(2, _translate("file_widget", "Selected channels only"))
        self.channels_tree.setToolTip(_translate("file_widget", "Double click channel to see extended information"))
        self.channels_tree.headerItem().setText(0, _translate("file_widget", "Channels"))
        self.load_channel_list_btn.setToolTip(_translate("file_widget", "Load offline windows"))
        self.save_channel_list_btn.setToolTip(_translate("file_widget", "Save offline windows"))
        self.select_all_btn.setToolTip(_translate("file_widget", "Select all the channels"))
        self.clear_channels_btn.setToolTip(_translate("file_widget", "Clear all selected channels"))
        self.advanced_search_btn.setToolTip(_translate("file_widget", "Search and select channels"))
        self.create_window_btn.setToolTip(_translate("file_widget", "Create window"))
        self.aspects.setTabText(self.aspects.indexOf(self.channels_tab), _translate("file_widget", "Channels"))
        self.filter_view.setItemText(0, _translate("file_widget", "Natural sort"))
        self.filter_view.setItemText(1, _translate("file_widget", "Internal file structure"))
        self.filter_view.setItemText(2, _translate("file_widget", "Selected channels only"))
        self.filter_tree.setToolTip(_translate("file_widget", "Double click channel to see extended information"))
        self.filter_tree.headerItem().setText(0, _translate("file_widget", "Channels"))
        self.load_filter_list_btn.setToolTip(_translate("file_widget", "Load channel selection list"))
        self.save_filter_list_btn.setToolTip(_translate("file_widget", "Save channel selection list"))
        self.clear_filter_btn.setToolTip(_translate("file_widget", "Clear selection"))
        self.advanced_serch_filter_btn.setToolTip(_translate("file_widget", "Search and select channels"))
        self.label.setText(_translate("file_widget", "All selected channels"))
        self.selected_filter_channels.setSortingEnabled(True)
        self.cut_group.setTitle(_translate("file_widget", "Cut"))
        self.label_59.setText(_translate("file_widget", "Start"))
        self.cut_stop.setSuffix(_translate("file_widget", "s"))
        self.whence.setText(_translate("file_widget", "Start relative to first time stamp"))
        self.label_60.setText(_translate("file_widget", "End"))
        self.cut_start.setSuffix(_translate("file_widget", "s"))
        self.cut_time_from_zero.setText(_translate("file_widget", "Time from 0s"))
        self.resample_group.setTitle(_translate("file_widget", "Resample"))
        self.raster_type_step.setText(_translate("file_widget", "step"))
        self.raster.setSuffix(_translate("file_widget", "s"))
        self.resample_time_from_zero.setText(_translate("file_widget", "Time from 0s"))
        self.raster_type_channel.setText(_translate("file_widget", "channel"))
        self.raster_search_btn.setToolTip(_translate("file_widget", "Search raster channel"))
        self.groupBox_10.setTitle(_translate("file_widget", "Ouput format"))
        self.output_format.setItemText(0, _translate("file_widget", "MDF"))
        self.output_format.setItemText(1, _translate("file_widget", "CSV"))
        self.output_format.setItemText(2, _translate("file_widget", "HDF5"))
        self.output_format.setItemText(3, _translate("file_widget", "MAT"))
        self.output_format.setItemText(4, _translate("file_widget", "Parquet"))
        self.mdf_split_size.setSuffix(_translate("file_widget", "MB"))
        self.label_29.setText(_translate("file_widget", "Compression"))
        self.mdf_split.setText(_translate("file_widget", "Split data blocks"))
        self.label_27.setText(_translate("file_widget", "Version"))
        self.groupBox_9.setTitle(_translate("file_widget", "Scramble"))
        self.scramble_btn.setText(_translate("file_widget", "Scramble texts"))
        self.label_61.setText(_translate("file_widget", "Anonymize the measurements: scramble all texts and replace them with random strings"))
        self.label_28.setText(_translate("file_widget", "Split size "))
        self.time_as_date.setText(_translate("file_widget", "Time as date"))
        self.time_from_zero.setText(_translate("file_widget", "Time from 0s"))
        self.reduce_memory_usage.setText(_translate("file_widget", "Reduce  memory usage"))
        self.label_67.setText(_translate("file_widget", "Compression"))
        self.label_65.setText(_translate("file_widget", "Empty channels"))
        self.single_time_base.setText(_translate("file_widget", "Single time base"))
        self.use_display_names.setText(_translate("file_widget", "Use display names"))
        self.raw.setText(_translate("file_widget", "Raw values"))
        self.use_display_names_mat.setText(_translate("file_widget", "Use display names"))
        self.label_19.setText(_translate("file_widget", ".mat oned_as"))
        self.time_from_zero_mat.setText(_translate("file_widget", "Time from 0s"))
        self.label_70.setText(_translate("file_widget", "Compression"))
        self.label_69.setText(_translate("file_widget", ".mat format"))
        self.single_time_base_mat.setText(_translate("file_widget", "Single time base"))
        self.reduce_memory_usage_mat.setText(_translate("file_widget", "Reduce  memory usage"))
        self.time_as_date_mat.setText(_translate("file_widget", "Time as date"))
        self.label_68.setText(_translate("file_widget", "Empty channels"))
        self.raw_mat.setText(_translate("file_widget", "Raw values"))
        self.quotechar.setText(_translate("file_widget", "\""))
        self.label_5.setText(_translate("file_widget", "Quote Char"))
        self.use_display_names_csv.setText(_translate("file_widget", "Use display names"))
        self.single_time_base_csv.setText(_translate("file_widget", "Single time base"))
        self.lineterminator.setText(_translate("file_widget", "\\r\\n"))
        self.time_as_date_csv.setText(_translate("file_widget", "Time as date"))
        self.raw_csv.setText(_translate("file_widget", "Raw values"))
        self.label_2.setText(_translate("file_widget", "Delimiter"))
        self.label_3.setText(_translate("file_widget", "Escape Char"))
        self.escapechar.setPlaceholderText(_translate("file_widget", "None"))
        self.time_from_zero_csv.setText(_translate("file_widget", "Time from 0s"))
        self.label_4.setText(_translate("file_widget", "Line Terminator"))
        self.doublequote.setText(_translate("file_widget", "Double quote"))
        self.label_6.setText(_translate("file_widget", "Quoting"))
        self.quoting.setItemText(0, _translate("file_widget", "ALL"))
        self.quoting.setItemText(1, _translate("file_widget", "MINIMAL"))
        self.quoting.setItemText(2, _translate("file_widget", "NONNUMERIC"))
        self.quoting.setItemText(3, _translate("file_widget", "NONE"))
        self.delimiter.setText(_translate("file_widget", ","))
        self.label_66.setText(_translate("file_widget", "Empty channels"))
        self.apply_btn.setText(_translate("file_widget", "Apply"))
        self.aspects.setTabText(self.aspects.indexOf(self.modify), _translate("file_widget", "Modify && Export"))
        self.label_12.setText(_translate("file_widget", "Prefix"))
        self.groupBox_2.setTitle(_translate("file_widget", "MDF"))
        self.label__1.setText(_translate("file_widget", "Compression"))
        self.extract_bus_btn.setText(_translate("file_widget", "Extract Bus signals"))
        self.label_24.setText(_translate("file_widget", "Version"))
        self.load_can_database_btn.setText(_translate("file_widget", "Load CAN database"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("file_widget", "CAN"))
        self.load_lin_database_btn.setText(_translate("file_widget", "Load LIN database"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("file_widget", "LIN"))
        self.groupBox_3.setTitle(_translate("file_widget", "CSV"))
        self.label_10.setText(_translate("file_widget", "Quote Char"))
        self.single_time_base_bus.setText(_translate("file_widget", "Single time base"))
        self.doublequote_bus.setText(_translate("file_widget", "Double quote"))
        self.label_23.setText(_translate("file_widget", "Raster"))
        self.label_25.setText(_translate("file_widget", "Empty channels"))
        self.label_9.setText(_translate("file_widget", "Escape Char"))
        self.label_7.setText(_translate("file_widget", "Quoting"))
        self.label_11.setText(_translate("file_widget", "Line Terminator"))
        self.bus_time_as_date.setText(_translate("file_widget", "Time as date"))
        self.time_from_zero_bus.setText(_translate("file_widget", "Time from 0s"))
        self.label_8.setText(_translate("file_widget", "Delimiter"))
        self.ignore_invalid_signals_csv.setToolTip(_translate("file_widget", "checks if all samples are eauql to the maximum teoretical signal value"))
        self.ignore_invalid_signals_csv.setText(_translate("file_widget", "Ignore invalid signals"))
        self.export_raster_bus.setSuffix(_translate("file_widget", "s"))
        self.delimiter_bus.setText(_translate("file_widget", ","))
        self.escapechar_bus.setPlaceholderText(_translate("file_widget", "None"))
        self.lineterminator_bus.setText(_translate("file_widget", "\\r\\n"))
        self.quotechar_bus.setText(_translate("file_widget", "\""))
        self.quoting_bus.setItemText(0, _translate("file_widget", "ALL"))
        self.quoting_bus.setItemText(1, _translate("file_widget", "MINIMAL"))
        self.quoting_bus.setItemText(2, _translate("file_widget", "NONNUMERIC"))
        self.quoting_bus.setItemText(3, _translate("file_widget", "NONE"))
        self.extract_bus_csv_btn.setText(_translate("file_widget", "Export to CSV         "))
        self.consolidated_j1939.setText(_translate("file_widget", "Consolidated J1939 (single group for all messages with common PGN)"))
        self.aspects.setTabText(self.aspects.indexOf(self.extract_bus_tab), _translate("file_widget", "Bus Logging"))
        self.info.headerItem().setText(0, _translate("file_widget", "Cathegory"))
        self.info.headerItem().setText(1, _translate("file_widget", "Value"))
        self.aspects.setTabText(self.aspects.indexOf(self.info_tab), _translate("file_widget", "Info"))
        self.aspects.setTabText(self.aspects.indexOf(self.attachments_tab), _translate("file_widget", "Attachments"))
from asammdf.gui.widgets.list import MinimalListWidget
from asammdf.gui.widgets.tree import TreeWidget
from . import resource_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'define_channel_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ComputedChannel(object):
    def setupUi(self, ComputedChannel):
        ComputedChannel.setObjectName("ComputedChannel")
        ComputedChannel.resize(523, 395)
        ComputedChannel.setMaximumSize(QtCore.QSize(16777215, 400))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/plus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        ComputedChannel.setWindowIcon(icon)
        self.gridLayout = QtWidgets.QGridLayout(ComputedChannel)
        self.gridLayout.setObjectName("gridLayout")
        self.apply_btn = QtWidgets.QPushButton(ComputedChannel)
        self.apply_btn.setObjectName("apply_btn")
        self.gridLayout.addWidget(self.apply_btn, 1, 1, 1, 1)
        self.cancel_btn = QtWidgets.QPushButton(ComputedChannel)
        self.cancel_btn.setObjectName("cancel_btn")
        self.gridLayout.addWidget(self.cancel_btn, 1, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 0, 1, 1)
        self.tabs = QtWidgets.QTabWidget(ComputedChannel)
        self.tabs.setObjectName("tabs")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.computation_grid_layout = QtWidgets.QGridLayout(self.tab)
        self.computation_grid_layout.setObjectName("computation_grid_layout")
        self.op = QtWidgets.QComboBox(self.tab)
        self.op.setObjectName("op")
        self.computation_grid_layout.addWidget(self.op, 1, 0, 1, 1)
        self.operand2 = QtWidgets.QComboBox(self.tab)
        self.operand2.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.operand2.setObjectName("operand2")
        self.computation_grid_layout.addWidget(self.operand2, 2, 0, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(29, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.computation_grid_layout.addItem(spacerItem1, 1, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.computation_grid_layout.addItem(spacerItem2, 5, 0, 1, 1)
        self.operand1 = QtWidgets.QComboBox(self.tab)
        self.operand1.setMinimumSize(QtCore.QSize(380, 20))
        self.operand1.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.operand1.setObjectName("operand1")
        self.computation_grid_layout.addWidget(self.operand1, 0, 0, 1, 2)
        spacerItem3 = QtWidgets.QSpacerItem(92, 18, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.computation_grid_layout.addItem(spacerItem3, 4, 2, 1, 1)
        self.unit = QtWidgets.QLineEdit(self.tab)
        self.unit.setObjectName("unit")
        self.computation_grid_layout.addWidget(self.unit, 4, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.computation_grid_layout.addItem(spacerItem4, 4, 3, 1, 1)
        self.name = QtWidgets.QLineEdit(self.tab)
        self.name.setInputMask("")
        self.name.setText("")
        self.name.setObjectName("name")
        self.computation_grid_layout.addWidget(self.name, 3, 0, 1, 4)
        self.computation_grid_layout.setColumnStretch(2, 1)
        self.computation_grid_layout.setColumnStretch(3, 1)
        self.tabs.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.function_unit = QtWidgets.QLineEdit(self.tab_2)
        self.function_unit.setObjectName("function_unit")
        self.gridLayout_4.addWidget(self.function_unit, 3, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(92, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem5, 1, 2, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(184, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem6, 3, 1, 1, 1)
        self.channel = QtWidgets.QComboBox(self.tab_2)
        self.channel.setObjectName("channel")
        self.gridLayout_4.addWidget(self.channel, 1, 0, 1, 2)
        self.function_name = QtWidgets.QLineEdit(self.tab_2)
        self.function_name.setObjectName("function_name")
        self.gridLayout_4.addWidget(self.function_name, 2, 0, 1, 3)
        self.function = QtWidgets.QComboBox(self.tab_2)
        self.function.setMinimumSize(QtCore.QSize(380, 20))
        self.function.setObjectName("function")
        self.gridLayout_4.addWidget(self.function, 0, 0, 1, 2)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem7, 4, 0, 1, 1)
        self.tabs.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.expression_name = QtWidgets.QLineEdit(self.tab_3)
        self.expression_name.setObjectName("expression_name")
        self.gridLayout_2.addWidget(self.expression_name, 2, 0, 1, 2)
        self.expression_unit = QtWidgets.QLineEdit(self.tab_3)
        self.expression_unit.setObjectName("expression_unit")
        self.gridLayout_2.addWidget(self.expression_unit, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.tab_3)
        self.label.setTextFormat(QtCore.Qt.RichText)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 2)
        spacerItem8 = QtWidgets.QSpacerItem(234, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem8, 3, 1, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem9, 4, 0, 1, 1)
        self.expression = QtWidgets.QPlainTextEdit(self.tab_3)
        self.expression.setObjectName("expression")
        self.gridLayout_2.addWidget(self.expression, 1, 0, 1, 2)
        self.tabs.addTab(self.tab_3, "")
        self.gridLayout.addWidget(self.tabs, 0, 0, 1, 3)

        self.retranslateUi(ComputedChannel)
        self.tabs.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(ComputedChannel)

    def retranslateUi(self, ComputedChannel):
        _translate = QtCore.QCoreApplication.translate
        ComputedChannel.setWindowTitle(_translate("ComputedChannel", "Define new channel"))
        self.apply_btn.setText(_translate("ComputedChannel", "Apply"))
        self.cancel_btn.setText(_translate("ComputedChannel", "Cancel"))
        self.unit.setPlaceholderText(_translate("ComputedChannel", "channel unit"))
        self.name.setPlaceholderText(_translate("ComputedChannel", "channel name"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab), _translate("ComputedChannel", "Simple computation"))
        self.function_unit.setPlaceholderText(_translate("ComputedChannel", "channel unit"))
        self.function_name.setPlaceholderText(_translate("ComputedChannel", "channel name"))
        self.function.setToolTip(_translate("ComputedChannel", "see numpy documentation"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_2), _translate("ComputedChannel", "Function"))
        self.expression_name.setPlaceholderText(_translate("ComputedChannel", "channel name"))
        self.expression_unit.setPlaceholderText(_translate("ComputedChannel", "channel unit"))
        self.label.setText(_translate("ComputedChannel", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The expression is evaluated using the <span style=\" font-style:italic;\">numexpr </span>library. Have a look at the <a href=\"https://numexpr.readthedocs.io/projects/NumExpr3/en/latest/user_guide.html\"><span style=\" text-decoration: underline; color:#0000ff;\">Numexpr documentation</span></a> for supported operators and function.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The signal names must be enclosed by double curly braces: <span style=\" font-weight:600; color:#ff0000;\">{{</span>Signal_name<span style=\" font-weight:600; color:#ff0000;\">}}</span></p></body></html>"))
        self.expression.setPlaceholderText(_translate("ComputedChannel", "enter your expression here. Example: ({{Sig1}} + {{Sig2}}) / ({{Sig3}} - {{Sig4}}) + 7.8"))
        self.tabs.setTabText(self.tabs.indexOf(self.tab_3), _translate("ComputedChannel", "Expression"))
from . import resource_rc



#!/usr/bin/env python
from pathlib import Path
import tempfile
import unittest
import urllib
from zipfile import ZipFile

import numpy as np

from asammdf import MDF


class TestCANBusLogging(unittest.TestCase):

    tempdir_obd = None
    tempdir_j1939 = None

    @classmethod
    def setUpClass(cls):

        cls.tempdir_obd = tempfile.TemporaryDirectory()
        cls.tempdir_j1939 = tempfile.TemporaryDirectory()

        url = "https://github.com/danielhrisca/asammdf/files/4328945/OBD2-DBC-MDF4.zip"
        urllib.request.urlretrieve(url, "test.zip")
        ZipFile(r"test.zip").extractall(cls.tempdir_obd.name)
        Path("test.zip").unlink()

        url = "https://github.com/danielhrisca/asammdf/files/4076869/J1939-DBC-MDF4.zip"
        urllib.request.urlretrieve(url, "test.zip")
        ZipFile(r"test.zip").extractall(cls.tempdir_j1939.name)
        Path("test.zip").unlink()

    def test_obd_extract(self):
        print("OBD extract")

        temp_dir = Path(TestCANBusLogging.tempdir_obd.name)

        for file in temp_dir.iterdir():
            print(file)

        mdf = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".mf4"
        ][0]

        mdf = MDF(mdf)

        dbc = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".dbc"
        ][0]

        signals = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".npy"
        ]

        out = mdf.extract_bus_logging({"CAN": [(dbc, 0)]})

        for signal in signals:
            name = signal.stem

            target = np.load(signal)
            sig = out.get(name)

            self.assertTrue(
                np.array_equal(sig.samples, target), f"{name} {sig} {target}"
            )

    def test_j1939_extract(self):
        print("J1939 extract")

        temp_dir = Path(TestCANBusLogging.tempdir_j1939.name)

        mdf = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".mf4"
        ][0]

        mdf = MDF(mdf)

        dbc = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".dbc"
        ][0]

        signals = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".npy"
        ]

        out = mdf.extract_bus_logging({"CAN": [(dbc, 0)]})

        for signal in signals:
            name = signal.stem

            target = np.load(signal)
            values = out.get(name).samples

            self.assertTrue(np.array_equal(values, target))

    def test_j1939_get_can_signal(self):
        print("J1939 get CAN signal")

        temp_dir = Path(TestCANBusLogging.tempdir_j1939.name)

        mdf = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".mf4"
        ][0]

        mdf = MDF(mdf)

        dbc = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".dbc"
        ][0]

        signals = [
            input_file
            for input_file in temp_dir.iterdir()
            if input_file.suffix == ".npy"
        ]

        for signal in signals:
            name = signal.stem

            target = np.load(signal)

            values = mdf.get_can_signal(name=name, database=str(dbc)).samples

            self.assertTrue(np.array_equal(values, target))

            values = mdf.get_bus_signal("CAN", name=name, database=str(dbc)).samples

            self.assertTrue(np.array_equal(values, target))


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
import datetime
import logging
from traceback import format_exc

import numpy as np
import numpy.core.defchararray as npchar
import pandas as pd
from PyQt5 import QtCore, QtGui, QtWidgets

from ...blocks.utils import (
    csv_bytearray2hex,
    csv_int2bin,
    csv_int2hex,
    pandas_query_compatible,
)
from ..utils import run_thread_with_progress
from .tabular_base import TabularBase, TabularTreeItem
from .tabular_filter import TabularFilter

logger = logging.getLogger("asammdf.gui")
LOCAL_TIMEZONE = datetime.datetime.now(datetime.timezone.utc).astimezone().tzinfo


class Tabular(TabularBase):
    add_channels_request = QtCore.pyqtSignal(list)

    def __init__(
        self, signals=None, start=0, format="phys", ranges=None, *args, **kwargs
    ):
        # super().__init__(*args, **kwargs)

        self.signals_descr = {}
        self.start = start
        self.pattern = {}
        self.format = format

        if signals is None:
            signals = pd.DataFrame()
        else:
            index = pd.Series(np.arange(len(signals), dtype="u8"), index=signals.index)
            signals["Index"] = index

            signals["timestamps"] = signals.index
            signals.set_index(index, inplace=True)
            dropped = {}

            for name_ in signals.columns:
                col = signals[name_]
                if col.dtype.kind == "O":
                    if name_.endswith("DataBytes"):
                        try:
                            sizes = signals[name_.replace("DataBytes", "DataLength")]
                        except:
                            sizes = None
                        dropped[name_] = pd.Series(
                            csv_bytearray2hex(
                                col,
                                sizes,
                            ),
                            index=signals.index,
                        )

                    elif name_.endswith("Data Bytes"):
                        try:
                            sizes = signals[name_.replace("Data Bytes", "Data Length")]
                        except:
                            sizes = None
                        dropped[name_] = pd.Series(
                            csv_bytearray2hex(
                                col,
                                sizes,
                            ),
                            index=signals.index,
                        )

                    elif col.dtype.name != "category":
                        try:
                            dropped[name_] = pd.Series(
                                csv_bytearray2hex(col), index=signals.index
                            )
                        except:
                            pass

                    self.signals_descr[name_] = 0

                elif col.dtype.kind == "S":
                    try:
                        dropped[name_] = pd.Series(
                            npchar.decode(col, "utf-8"), index=signals.index
                        )
                    except:
                        dropped[name_] = pd.Series(
                            npchar.decode(col, "latin-1"), index=signals.index
                        )
                    self.signals_descr[name_] = 0
                else:
                    self.signals_descr[name_] = 0

            signals = signals.drop(columns=["Index", *list(dropped)])
            for name, s in dropped.items():
                signals[name] = s

            names = list(signals.columns)
            names = [
                "timestamps",
                *[name for name in names if name.endswith((".ID", ".DataBytes"))],
                *[
                    name
                    for name in names
                    if name != "timestamps" and not name.endswith((".ID", ".DataBytes"))
                ],
            ]
            signals = signals[names]

        super().__init__(signals, ranges)
        self.format_selection.setCurrentText(format)

        self._original_timestamps = signals["timestamps"]
        self._original_ts_series = pd.Series(
            self._original_timestamps,
            index=index,
        )

        # self.build(self.signals, True, ranges=ranges)

        prefixes = set()
        for name in signals.columns:
            while "." in name:
                name = name.rsplit(".", 1)[0]
                prefixes.add(f"{name}.")

        self.filters.minimal_menu = True

        self.prefix.insertItems(0, sorted(prefixes, key=lambda x: (-len(x), x)))
        self.prefix.setEnabled(False)

        self.prefix.currentIndexChanged.connect(self.prefix_changed)

        if prefixes:
            self.remove_prefix.setCheckState(QtCore.Qt.Checked)

        self._settings = QtCore.QSettings()
        integer_mode = self._settings.value("tabular_format", "phys")

        self.format_selection.setCurrentText(integer_mode)

        self.tree.dataView.setAcceptDrops(True)
        self.tree.dataView.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.tree.dataView.setDropIndicatorShown(True)
        self.tree.dataView.setDefaultDropAction(QtCore.Qt.MoveAction)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'range_editor_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_RangeDialog(object):
    def setupUi(self, RangeDialog):
        RangeDialog.setObjectName("RangeDialog")
        RangeDialog.resize(834, 485)
        RangeDialog.setSizeGripEnabled(True)
        RangeDialog.setModal(True)
        self.gridLayout = QtWidgets.QGridLayout(RangeDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.ranges = MinimalListWidget(RangeDialog)
        self.ranges.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.ranges.setDefaultDropAction(QtCore.Qt.MoveAction)
        self.ranges.setObjectName("ranges")
        self.gridLayout.addWidget(self.ranges, 0, 0, 7, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 271, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 4, 1, 1, 1)
        self.reset_btn = QtWidgets.QPushButton(RangeDialog)
        self.reset_btn.setObjectName("reset_btn")
        self.gridLayout.addWidget(self.reset_btn, 3, 1, 1, 1)
        self.cancel_btn = QtWidgets.QPushButton(RangeDialog)
        self.cancel_btn.setObjectName("cancel_btn")
        self.gridLayout.addWidget(self.cancel_btn, 6, 1, 1, 1)
        self.apply_btn = QtWidgets.QPushButton(RangeDialog)
        self.apply_btn.setObjectName("apply_btn")
        self.gridLayout.addWidget(self.apply_btn, 5, 1, 1, 1)
        self.insert_btn = QtWidgets.QPushButton(RangeDialog)
        self.insert_btn.setObjectName("insert_btn")
        self.gridLayout.addWidget(self.insert_btn, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem1, 1, 1, 1, 1)
        self.gridLayout.setColumnStretch(0, 1)
        self.gridLayout.setRowStretch(4, 1)

        self.retranslateUi(RangeDialog)
        QtCore.QMetaObject.connectSlotsByName(RangeDialog)
        RangeDialog.setTabOrder(self.ranges, self.apply_btn)
        RangeDialog.setTabOrder(self.apply_btn, self.cancel_btn)

    def retranslateUi(self, RangeDialog):
        _translate = QtCore.QCoreApplication.translate
        RangeDialog.setWindowTitle(_translate("RangeDialog", "Edit value range colors"))
        self.reset_btn.setText(_translate("RangeDialog", "Reset"))
        self.cancel_btn.setText(_translate("RangeDialog", "Cancel"))
        self.apply_btn.setText(_translate("RangeDialog", "Apply"))
        self.insert_btn.setText(_translate("RangeDialog", "Insert range"))
from asammdf.gui.widgets.list import MinimalListWidget
